# neuronpedia-autointerp-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import neuronpedia_autointerp_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import neuronpedia_autointerp_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import neuronpedia_autointerp_client
from neuronpedia_autointerp_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to /v1
# See configuration.py for a list of all supported configuration parameters.
configuration = neuronpedia_autointerp_client.Configuration(
    host = "/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: SimpleSecretAuth
configuration.api_key['SimpleSecretAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['SimpleSecretAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with neuronpedia_autointerp_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = neuronpedia_autointerp_client.DefaultApi(api_client)
    explain_default_post_request = neuronpedia_autointerp_client.ExplainDefaultPostRequest() # ExplainDefaultPostRequest | 

    try:
        # Generate an explanation for neuron/feature behavior using the default explainer
        api_response = api_instance.explain_default_post(explain_default_post_request)
        print("The response of DefaultApi->explain_default_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->explain_default_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to */v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**explain_default_post**](docs/DefaultApi.md#explain_default_post) | **POST** /explain/default | Generate an explanation for neuron/feature behavior using the default explainer
*DefaultApi* | [**score_embedding_post**](docs/DefaultApi.md#score_embedding_post) | **POST** /score/embedding | Score an explanation using embedding similarity, using the dunzhang/stella_en_400M_v5 model.
*DefaultApi* | [**score_fuzz_detection_post**](docs/DefaultApi.md#score_fuzz_detection_post) | **POST** /score/fuzz-detection | Score an explanation using fuzzing or detection methods


## Documentation For Models

 - [ExplainDefaultPost200Response](docs/ExplainDefaultPost200Response.md)
 - [ExplainDefaultPostRequest](docs/ExplainDefaultPostRequest.md)
 - [NPActivation](docs/NPActivation.md)
 - [NPScoreFuzzDetectionType](docs/NPScoreFuzzDetectionType.md)
 - [ScoreEmbeddingPost200Response](docs/ScoreEmbeddingPost200Response.md)
 - [ScoreEmbeddingPost200ResponseBreakdownInner](docs/ScoreEmbeddingPost200ResponseBreakdownInner.md)
 - [ScoreEmbeddingPostRequest](docs/ScoreEmbeddingPostRequest.md)
 - [ScoreFuzzDetectionPost200Response](docs/ScoreFuzzDetectionPost200Response.md)
 - [ScoreFuzzDetectionPost200ResponseBreakdownInner](docs/ScoreFuzzDetectionPost200ResponseBreakdownInner.md)
 - [ScoreFuzzDetectionPostRequest](docs/ScoreFuzzDetectionPostRequest.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="SimpleSecretAuth"></a>
### SimpleSecretAuth

- **Type**: API key
- **API key parameter name**: X-SECRET-KEY
- **Location**: HTTP header


## Author

johnny@neuronpedia.org


